==> kdepim-3.3.2.tar.bz2: kdepim-3.3.2/kaddressbook/interfaces/configurewidget.cpp <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include <kabc/addressbook.h>

#include "configurewidget.h"

using namespace KAB;

ConfigureWidget::ConfigureWidget( KABC::AddressBook *ab, QWidget *parent,
                                  const char *name )
  : QWidget( parent, name ), mAddressBook( ab )
{
}

ConfigureWidget::~ConfigureWidget()
{
}

void ConfigureWidget::restoreSettings( KConfig* )
{
  // should be reimplemented in the views, extensions etc.
}

void ConfigureWidget::saveSettings( KConfig* )
{
  // should be reimplemented in the views, extensions etc.
}

KABC::AddressBook *ConfigureWidget::addressBook() const
{
  return mAddressBook;
}

==> kdepim-3.5.9.tar.bz2: kdepim-3.5.9/kaddressbook/interfaces/configurewidget.cpp <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include <kabc/addressbook.h>

#include "configurewidget.h"

using namespace KAB;

ConfigureWidget::ConfigureWidget( KABC::AddressBook *ab, QWidget *parent,
                                  const char *name )
  : QWidget( parent, name ), mAddressBook( ab )
{
}

ConfigureWidget::~ConfigureWidget()
{
}

void ConfigureWidget::restoreSettings( KConfig* )
{
  // should be reimplemented in the views, extensions etc.
}

void ConfigureWidget::saveSettings( KConfig* )
{
  // should be reimplemented in the views, extensions etc.
}

KABC::AddressBook *ConfigureWidget::addressBook() const
{
  return mAddressBook;
}
